==> aliyun-python-sdk-elasticsearch-3.0.7.tar.gz: aliyun-python-sdk-elasticsearch-3.0.7/aliyunsdkelasticsearch/request/v20170613/GetTransferableNodesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest

class GetTransferableNodesRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'elasticsearch', '2017-06-13', 'GetTransferableNodes','elasticsearch')
		self.set_uri_pattern('/openapi/instances/[InstanceId]/transferable-nodes')
		self.set_method('GET')

	def get_InstanceId(self):
		return self.get_path_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_path_param('InstanceId',InstanceId)

	def get_nodeType(self):
		return self.get_query_params().get('nodeType')

	def set_nodeType(self,nodeType):
		self.add_query_param('nodeType',nodeType)

	def get_count(self):
		return self.get_query_params().get('count')

	def set_count(self,count):
		self.add_query_param('count',count)

==> aliyun-python-sdk-elasticsearch-3.1.1.tar.gz: aliyun-python-sdk-elasticsearch-3.1.1/aliyunsdkelasticsearch/request/v20170613/GetTransferableNodesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkelasticsearch.endpoint import endpoint_data

class GetTransferableNodesRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'elasticsearch', '2017-06-13', 'GetTransferableNodes','elasticsearch')
		self.set_uri_pattern('/openapi/instances/[InstanceId]/transferable-nodes')
		self.set_method('GET')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_InstanceId(self): # string
		return self.get_path_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # string
		self.add_path_param('InstanceId', InstanceId)
	def get_nodeType(self): # string
		return self.get_query_params().get('nodeType')

	def set_nodeType(self, nodeType):  # string
		self.add_query_param('nodeType', nodeType)
	def get_count(self): # integer
		return self.get_query_params().get('count')

	def set_count(self, count):  # integer
		self.add_query_param('count', count)
